@@ -3,24 +3,28 @@ import datetime
 import logging
 import re
 from functools import wraps
+from textwrap import shorten
 from urllib.parse import urljoin
 
 from qiskit.providers import JobStatus
 from tornado.escape import json_decode, json_encode
-from tornado.httpclient import AsyncHTTPClient, HTTPClient, HTTPRequest
+from tornado.httpclient import (AsyncHTTPClient, HTTPClient, HTTPError,
+                                HTTPRequest)
 from tornado.httputil import url_concat
 
 from qctic.schemas import BackendStatusSchema, GetJobsQuerySchema, JobSchema
 
 _SCHEME_REGEX = r"^.+://.*"
 _SCHEME_DEFAULT = "http"
+_BODY_WIDTH = 1024
 
 _logger = logging.getLogger(__name__)
 
 
 def _format_req(req):
     base = "{} {}".format(req.method, req.url)
-    return "{}\n{}".format(base, req.body) if req.body else base
+    body = shorten(req.body.decode(), width=_BODY_WIDTH) if req.body else None
+    return "{}\n{}".format(base, body) if body else base
 
 
 def _assert_synchronous(func):
@@ -37,6 +41,10 @@ def _assert_synchronous(func):
     return wrapper
 
 
+class QCticAPIError(Exception):
+    pass
+
+
 class QCticAPI:
     """Class that represents the Erwin simulation API interface."""
 
@@ -159,6 +167,15 @@ class QCticAPI:
         request_params.update(kwargs)
         return HTTPRequest(**request_params)
 
+    async def _fetch(self, *args, **kwargs):
+        try:
+            return await self.client.fetch(*args, **kwargs)
+        except HTTPError as ex:
+            err = json_decode(ex.response.body)
+            _logger.warning("Error on API request: %s", err)
+            err_msg = "[{}] {}".format(err.get("name"), err.get("description"))
+            raise QCticAPIError(err_msg)
+
     async def get_job(self, job_id):
         """Retrieves a single Job from the API.
 
@@ -174,7 +191,7 @@ class QCticAPI:
             method="GET")
 
         _logger.debug(_format_req(req))
-        res = await self.client.fetch(req)
+        res = await self._fetch(req)
 
         return JobSchema().load(json_decode(res.body))
 
@@ -203,7 +220,7 @@ class QCticAPI:
         req = self._request(url=url, method="GET")
 
         _logger.debug(_format_req(req))
-        res = await self.client.fetch(req)
+        res = await self._fetch(req)
 
         return [JobSchema().load(item) for item in json_decode(res.body)]
 
@@ -219,7 +236,7 @@ class QCticAPI:
             method="GET")
 
         _logger.debug(_format_req(req))
-        res = await self.client.fetch(req)
+        res = await self._fetch(req)
 
         return BackendStatusSchema().load(json_decode(res.body))
 
@@ -248,7 +265,7 @@ class QCticAPI:
             body=body)
 
         _logger.debug(_format_req(req))
-        await self.client.fetch(req)
+        await self._fetch(req)
 
     async def cancel_job(self, job_id):
         """Attempts to cancel a job that is currently active.
@@ -265,7 +282,7 @@ class QCticAPI:
             body=body)
 
         _logger.debug(_format_req(req))
-        await self.client.fetch(req)
+        await self._fetch(req)
 
     @_assert_synchronous
     def get_job_sync(self, job_id):
